==> haskell-incremental-parser-0.2.4.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-incremental-parser.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: incremental-parser
version: 0.2.4.1
id: incremental-parser-0.2.4.1-AFIVcJuwFHFLH3hjRV2xsT
key: incremental-parser-0.2.4.1-AFIVcJuwFHFLH3hjRV2xsT
license: GPL
copyright: (c) 2011-2015 Mario Blazevic
maintainer: blamario@yahoo.com
homepage: https://github.com/blamario/incremental-parser
synopsis: Generic parser library capable of providing partial results from partial input.
description:
    This package defines yet another parser combinator library. This one is implemented using the concept of Brzozowski
    derivatives, tweaked and optimized to work with any monoidal input type. Lists, ByteString, and Text are supported out
    of the box, as well as any other data type for which the monoid-subclasses package defines instances. If the parser
    result is also a monoid, its chunks can be extracted incrementally, before the complete input is parsed.
category: Parsing
author: Mario Blazevic
exposed: True
exposed-modules:
    Text.ParserCombinators.Incremental
    Text.ParserCombinators.Incremental.LeftBiasedLocal
    Text.ParserCombinators.Incremental.Symmetric
    Control.Applicative.Monoid
abi: e6e163ccf021e7e95dc019cfeaee3531
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/incremental-parser-0.2.4.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/incremental-parser-0.2.4.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/incremental-parser-0.2.4.1
hs-libraries: HSincremental-parser-0.2.4.1-AFIVcJuwFHFLH3hjRV2xsT
depends:
    base-4.9.0.0 monoid-subclasses-0.4.2.1-8KIAWXRIQBfFZoL4vhjpU4
haddock-interfaces: /usr/share/doc/haskell-incremental-parser/html/incremental-parser.haddock
haddock-html: /usr/share/doc/haskell-incremental-parser/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-incremental-parser-0.2.5-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-incremental-parser.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: incremental-parser
version: 0.2.5
id: incremental-parser-0.2.5-9Z9cf5eTOciai50iFcJsb
key: incremental-parser-0.2.5-9Z9cf5eTOciai50iFcJsb
license: GPL
copyright: (c) 2011-2016 Mario Blazevic
maintainer: blamario@yahoo.com
homepage: https://github.com/blamario/incremental-parser
synopsis: Generic parser library capable of providing partial results from partial input.
description:
    This package defines yet another parser combinator library. This one is implemented using the concept of Brzozowski
    derivatives, tweaked and optimized to work with any monoidal input type. Lists, ByteString, and Text are supported out
    of the box, as well as any other data type for which the monoid-subclasses package defines instances. If the parser
    result is also a monoid, its chunks can be extracted incrementally, before the complete input is parsed.
category: Parsing
author: Mario Blazevic
exposed: True
exposed-modules:
    Text.ParserCombinators.Incremental
    Text.ParserCombinators.Incremental.LeftBiasedLocal
    Text.ParserCombinators.Incremental.Symmetric
    Control.Applicative.Monoid
abi: deecc5e67c711aad0336fb2150527ad0
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/incremental-parser-0.2.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/incremental-parser-0.2.5
data-dir: /usr/share/arm-linux-ghc-8.0.1/incremental-parser-0.2.5
hs-libraries: HSincremental-parser-0.2.5-9Z9cf5eTOciai50iFcJsb
depends:
    base-4.9.0.0 monoid-subclasses-0.4.3-64OaxfJkDmoCi3HVQcUqFS
haddock-interfaces: /usr/share/doc/haskell-incremental-parser/html/incremental-parser.haddock
haddock-html: /usr/share/doc/haskell-incremental-parser/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
